"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.AmplifyAngularVisitor = void 0;
const tslib_1 = require("tslib");
const visitor_plugin_common_1 = require("@graphql-codegen/visitor-plugin-common");
const auto_bind_1 = tslib_1.__importDefault(require("auto-bind"));
const graphql_1 = require("graphql");
const change_case_all_1 = require("change-case-all");
class AmplifyAngularVisitor extends visitor_plugin_common_1.ClientSideBaseVisitor {
    constructor(schema, fragments, rawConfig, documents) {
        super(schema, fragments, rawConfig, {}, documents);
        (0, auto_bind_1.default)(this);
    }
    getImports() {
        return [
            `/* eslint-disable */`,
            `import { Injectable } from '@angular/core';`,
            `import API, { graphqlOperation } from '@aws-amplify/api-graphql';`,
        ];
    }
    buildOperation(node, documentVariableName, operationType, operationResultType, operationVariablesTypes) {
        const serviceName = (0, change_case_all_1.camelCase)(this.convertName(node));
        const firstChild = node.selectionSet.selections[0];
        let firstChildName;
        if (firstChild.kind === 'Field') {
            firstChildName = firstChild.name.value;
            operationResultType = `${operationResultType}['${firstChildName}']`;
        }
        const operations = (0, graphql_1.print)(node);
        const indentedOperations = operations.replace(/\n/g, '\n    ');
        const content = `
  async ${serviceName}(input:${operationVariablesTypes}): Promise<${operationResultType}> {
    const statement = \`${indentedOperations}\`;
    const response = (await API.graphql(
      graphqlOperation(statement, input)
    )) as any;
    return response.data${firstChildName != null ? `.${firstChildName}` : ''} as ${operationResultType};
  }`;
        return content;
    }
}
exports.AmplifyAngularVisitor = AmplifyAngularVisitor;
//# sourceMappingURL=visitor.js.map